Installation
===============

Dependencies
------------

``dsps`` requires `numpy <https://numpy.org/>`__, 
`jax <https://jax.readthedocs.io/en/latest/>`__, and 
`h5py <https://docs.h5py.org/en/stable/>`__.

Installing the latest release
-----------------------------

The latest release of ``dsps`` is available for installation with pip::

       pip install dsps

Alternatively, you can install the code using conda-forge::

       conda install -c conda-forge dsps


Installing the development branch
---------------------------------

You can also install dsps by downloading the source code or cloning 
`the GitHub repository <https://github.com/ArgonneCPAC/dsps/>`__,
and running the standard::

       pip install .

To use the latest code on the main branch, you'll need to install from source.
